@@ -19,11 +19,6 @@
 #include <KPtyProcess>
 #include <QTest>
 
-#include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5, 86, 0)
-#include <KPluginLoader>
-#endif
-
 // Konsole
 #include "../Pty.h"
 
@@ -50,10 +45,8 @@ void PartTest::initTestCase()
 void PartTest::testFdShell()
 {
     // Maybe https://bugreports.qt.io/browse/QTBUG-82351 ???
-#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
     QSKIP("Skipping on CI suse_tumbelweed_qt64", SkipSingle);
     return;
-#endif
 
     testFd(true);
 }
@@ -124,6 +117,7 @@ void PartTest::testFd(bool runShell)
     QTimer::singleShot(5000, dialog.data(), &QDialog::close);
     dialog.data()->exec();
 
+    delete terminalPart;
     delete dialog.data();
     ptyProcess.kill();
     ptyProcess.waitForFinished(1000);
@@ -131,7 +125,6 @@ void PartTest::testFd(bool runShell)
 
 KParts::Part *PartTest::createPart()
 {
-#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 86, 0)
     const KPluginMetaData metaData(QStringLiteral("konsolepart"));
     Q_ASSERT(metaData.isValid());
 
@@ -139,21 +132,8 @@ KParts::Part *PartTest::createPart()
     Q_ASSERT(result);
 
     return result.plugin;
-#else
-    auto konsolePartPlugin = KPluginLoader::findPlugin(QStringLiteral("konsolepart"));
-    if (konsolePartPlugin.isNull()) {
-        return nullptr;
-    }
-
-    KPluginFactory *factory = KPluginLoader(konsolePartPlugin).factory();
-    if (factory == nullptr) { // not found
-        return nullptr;
-    }
-
-    auto *terminalPart = factory->create<KParts::Part>(this);
-
-    return terminalPart;
-#endif
 }
 
 QTEST_MAIN(PartTest)
+
+#include "moc_PartTest.cpp"
