@@ -32,6 +32,7 @@
 #include <KLocalizedString>
 #include <KNotification>
 #include <KProcess>
+#include <KSelectAction>
 
 #ifndef Q_OS_WIN
 #include <KPtyDevice>
@@ -46,6 +47,7 @@
 #include "Pty.h"
 #include "SSHProcessInfo.h"
 #include "SessionController.h"
+#include "SessionGroup.h"
 #include "SessionManager.h"
 #include "ShellCommand.h"
 #include "Vt102Emulation.h"
@@ -160,7 +162,7 @@ void Session::openTeletype(int fd, bool runShell)
 
     // get notified when the pty process is finished
 #ifndef Q_OS_WIN
-    connect(_shellProcess, QOverload<int, QProcess::ExitStatus>::of(&Konsole::Pty::finished), this, &Konsole::Session::done);
+    connect(_shellProcess, &Konsole::Pty::finished, this, &Konsole::Session::done);
 #else
     connect(_shellProcess, &Konsole::Pty::finished, this, &Konsole::Session::done);
 #endif
@@ -1048,7 +1050,7 @@ void Session::done(int exitCode, QProcess::ExitStatus exitStatus)
 {
 #ifndef Q_OS_WIN
     // This slot should be triggered only one time
-    disconnect(_shellProcess, QOverload<int, QProcess::ExitStatus>::of(&Konsole::Pty::finished), this, &Konsole::Session::done);
+    disconnect(_shellProcess, &Konsole::Pty::finished, this, &Konsole::Session::done);
 #else
     disconnect(_shellProcess, &Konsole::Pty::finished, this, &Konsole::Session::done);
 #endif
@@ -1589,7 +1591,7 @@ void Session::startZModem(const QString &zmodem, const QString &dir, const QStri
 
     connect(_zmodemProc, &KProcess::readyReadStandardOutput, this, &Konsole::Session::zmodemReadAndSendBlock);
     connect(_zmodemProc, &KProcess::readyReadStandardError, this, &Konsole::Session::zmodemReadStatus);
-    connect(_zmodemProc, QOverload<int, QProcess::ExitStatus>::of(&KProcess::finished), this, &Konsole::Session::zmodemFinished);
+    connect(_zmodemProc, &KProcess::finished, this, &Konsole::Session::zmodemFinished);
 
     _zmodemProc->start();
 
@@ -1807,6 +1809,79 @@ void Session::setProfile(const QString &profileName)
     }
 }
 
+bool Session::copyInputToAllSessions()
+{
+    if (auto c = controller()) {
+        c->copyInputActions()->setCurrentItem(SessionController::CopyInputToAllTabsMode);
+        c->copyInputToAllTabs();
+        return true;
+    }
+
+    return false;
+}
+
+bool Session::copyInputToSessions(QList<int> sessionIds)
+{
+    if (auto c = controller()) {
+        auto sessions = new QList<Session *>();
+        c->copyInputActions()->setCurrentItem(SessionController::CopyInputToSelectedTabsMode);
+
+        for (auto sessionId : sessionIds) {
+            if (auto session = SessionManager::instance()->idToSession(sessionId))
+                sessions->append(session);
+            else
+                return false;
+        }
+
+        c->copyInputToSelectedTabs(sessions);
+        return true;
+    }
+
+    return false;
+}
+
+bool Session::copyInputToNone()
+{
+    if (auto c = controller()) {
+        c->copyInputActions()->setCurrentItem(SessionController::CopyInputToNoneMode);
+        c->copyInputToNone();
+        return true;
+    } else
+        return false;
+}
+
+QList<int> Session::copyingSessions()
+{
+    if (auto c = controller()) {
+        if (auto copyToGroup = c->copyToGroup()) {
+            QList<int> sessionIds;
+
+            for (auto session : copyToGroup->sessions()) {
+                sessionIds.append(session->sessionId());
+            }
+
+            sessionIds.removeAll(sessionId());
+            return sessionIds;
+        }
+    }
+
+    return QList<int>();
+}
+
+QList<int> Session::feederSessions()
+{
+    QList<int> feeders;
+
+    for (auto session : SessionManager::instance()->sessions()) {
+        if (session->copyingSessions().contains(sessionId()) && !feeders.contains(session->sessionId())) {
+            feeders.append(session->sessionId());
+        }
+    }
+
+    feeders.removeAll(sessionId());
+    return feeders;
+}
+
 int Session::foregroundProcessId()
 {
     int pid;
@@ -1994,4 +2069,12 @@ QColor Session::color() const
     return _tabColor;
 }
 
+SessionController *Session::controller()
+{
+    if (!_views.isEmpty())
+        return _views.first()->sessionController();
+
+    return nullptr;
+}
+
 #include "moc_Session.cpp"
